@@ -1,5 +1,5 @@
 # Initialization code
-# Copyright (C) 2020  Nguyễn Gia Phong
+# Copyright (C) 2020-2021  Nguyễn Gia Phong
 #
 # This file is part of Acanban.
 #
@@ -21,27 +21,36 @@ from __future__ import annotations
 from contextlib import asynccontextmanager
 from secrets import token_urlsafe
 from typing import Any, AsyncIterator
+from urllib.parse import urlsplit
 
-from quart import render_template
+from httpx import AsyncClient
+from quart import ResponseReturnValue, current_app, render_template
+from quart_auth import current_user
 from quart_trio import QuartTrio
 from rethinkdb import r
 from rethinkdb.trio_net.net_trio import TrioConnectionPool
 from trio import open_nursery
 
 from .auth import Authenticator, blueprint as auth
-from .config import RETHINKDB_DEFAULT
+from .config import IPFS_DEFAULT, RETHINKDB_DEFAULT
+from .ipfs import blueprint as ipfs
+from .project import blueprint as project
+from .user import blueprint as user
 
 __all__ = ['app']
 __doc__ = 'Academic Kanban'
-__version__ = '0.0.3'
+__version__ = '0.0.6'
 
 
 class Acanban(QuartTrio):
     """Acanban web application."""
 
     auth_manager: Authenticator
+    db_config = RETHINKDB_DEFAULT
     db_pool: TrioConnectionPool
-    rethinkdb_config = RETHINKDB_DEFAULT
+    ipfs_config = IPFS_DEFAULT
+    ipfs_gateway: AsyncClient
+    ipfs_api: AsyncClient
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
@@ -63,14 +72,16 @@ class Acanban(QuartTrio):
 
 app = Acanban(__name__)
 app.register_blueprint(auth)
+app.register_blueprint(ipfs)
+app.register_blueprint(user)
+app.register_blueprint(project)
 
 
 @app.before_serving
 async def create_db_pool() -> None:
     """Create RethinkDB connection pool."""
     r.set_loop_type('trio')
-    app.db_pool = r.ConnectionPool(
-        nursery=app.nursery, **app.rethinkdb_config)
+    app.db_pool = r.ConnectionPool(nursery=app.nursery, **app.db_config)
 
 
 @app.after_serving
@@ -79,7 +90,31 @@ async def close_db_pool() -> None:
     await app.db_pool.close()
 
 
+@app.before_serving
+async def open_ipfs_clients() -> None:
+    """Open HTTPX client for IPFS gateway and HTTP API."""
+    app.ipfs_gateway = AsyncClient(base_url=app.ipfs_config['gateway']['base'])
+    api_url = app.ipfs_config['api']['base']
+    app.ipfs_api = AsyncClient(base_url=api_url, headers={
+        'Accept': 'application/json', 'Host': urlsplit(api_url)[1],
+        'User-Agent': f'acanban/{__version__}'})
+
+
+@app.after_serving
+async def close_ipfs_clients() -> None:
+    """Close HTTPX client for IPFS gateway and HTTP API."""
+    await app.ipfs_gateway.aclose()
+    await app.ipfs_api.aclose()
+
+
 @app.route('/')
-async def index() -> str:
+async def index() -> ResponseReturnValue:
     """Return the index page."""
-    return await render_template('index.html')
+    if await current_user.is_authenticated:
+        username = current_user.key
+        my_projects = r.table('projects').get_all(username, index='members')
+        async with current_app.db_pool.connection() as connection:
+            projects = await my_projects.run(connection)
+        return await render_template('myproject.html', projects=projects)
+    else:
+        return await render_template('index.html')
