@@ -1,5 +1,5 @@
 # Common test fixtures
-# Copyright (C) 2020  Nguyễn Gia Phong
+# Copyright (C) 2020-2021  Nguyễn Gia Phong
 #
 # This file is part of Acanban.
 #
@@ -16,13 +16,16 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Acanban.  If not, see <https://www.gnu.org/licenses/>.
 
-from typing import AsyncIterator
+from typing import AsyncIterator, Awaitable, Callable, Optional
 
-from pytest import fixture
+from pytest import fixture, mark
 from quart.testing import QuartClient
 
 from acanban import Acanban, app
 
+ClientFactory = Callable[[Optional[str]], Awaitable[QuartClient]]
+parametrize = mark.parametrize
+
 
 @fixture(name='app')
 async def acanban() -> AsyncIterator[Acanban]:
@@ -33,3 +36,16 @@ async def acanban() -> AsyncIterator[Acanban]:
 def client(app: Acanban) -> QuartClient:
     """Return a Quart test client."""
     return app.test_client()
+
+
+@fixture
+async def user(client: QuartClient) -> ClientFactory:
+    """Return a coroutine which gives a logged client."""
+    async def login(username: Optional[str]) -> QuartClient:
+        """Return the logged client if username is not None."""
+        if username is None: return client  # I'm sorry Nathaniel!
+        form = {'username': username, 'password': username[::-1]}
+        await client.post('/login', form=form)
+        return client
+
+    return login
